NAME

Zipper - legacy token encoding and ajax URL compatibility helpers

SYNOPSIS

use Zipper qw(zip unzip Ajax);
my $token = zip("print qq{ok\\n};");

DESCRIPTION

This module recreates the small token and ajax helper surface expected by older bookmark code without carrying forward any project-specific logic.

FUNCTIONS

zip, unzip, acmdx, Ajax, __cmdx, _cmdx, _cmdp

Encode and decode token payloads and generate legacy-style ajax links.